@@ -128,15 +128,28 @@ pub fn parse_msgpack_to_predicate(expect_predicate: &str, iraw: &mut Individual)
                                         }
                                     } else if v_type == DataType::String as u8 {
                                         match read_string_from_msgpack(&mut cur) {
-                                            Ok(res) => {
-                                                let lang = match read_int(&mut cur) {
-                                                    Ok(res) => Lang::new_from_i64(res),
-                                                    Err(e) => {
-                                                        return Err(format!("value: fail read lang, err={:?}", e));
+                                            Ok(str) => {
+                                                let lang = match read_marker(&mut cur.clone()) {
+                                                    Ok(v) => match v {
+                                                        Marker::I8 => match read_int(&mut cur) {
+                                                            Ok(res) => Lang::new_from_i64(res),
+                                                            Err(e) => {
+                                                                return Err(format!("value: fail read lang, err={:?}", e));
+                                                            },
+                                                        },
+                                                        _ => match read_string_from_msgpack(&mut cur) {
+                                                            Ok(res) => Lang::new_from_str(&res),
+                                                            Err(e) => {
+                                                                return Err(format!("value: fail read lang, err={:?}", e));
+                                                            },
+                                                        },
+                                                    },
+                                                    _ => {
+                                                        return Err(format!("value: fail read lang"));
                                                     },
                                                 };
 
-                                                iraw.obj.add_string(&predicate, &res, lang);
+                                                iraw.obj.add_string(&predicate, &str, lang);
                                             },
                                             Err(e) => return Err(format!("value: expected {}, err={:?}", v_type, e)),
                                         }
